@@ -7,6 +7,7 @@
 #define __KERNEL__
 #include <linux/sched.h>
 
+#include "stacksize.h"
 #include "flags_sched.h"
 
 extern void prhead_vm_area_struct();
@@ -131,10 +132,19 @@ getinfo_fromtask(addr, ip, sp, stack)
 		*ip = tsk.thread.eip;
 	if (sp)
 		*sp = tsk.thread.esp;
-#endif
+#else
 #if defined(ARCH_ia64) || defined(ARCH_ppc)
+	if (ip)
+		*ip = 0;
 	if (sp)
 		*sp = tsk.thread.ksp;
+#else
+	/* others */
+	if (ip)
+		*ip = 0;
+	if (sp)
+		*sp = 0;
+#endif
 #endif
 	if (stack)
 		*stack = addr;
@@ -181,16 +191,6 @@ print_mm_struct(addr, vflag)
 	return (addr_t)mm.mmlist.next - OFFSET(struct mm_struct, mmlist);
 }
 
-#if defined(ARCH_alpha) || defined(ARCH_cris) || defined(ARCH_i386) || defined(ARCH_m68k) || defined(ARCH_mips) || defined(ARCH_ppc) || defined(ARCH_s390)
-#define	TASK_LOG_SIZE	1
-#elif defined(ARCH_ia64)
-#define TASK_LOG_SIZE	IA64_TASK_STRUCT_LOG_NUM_PAGES
-#elif defined(ARCH_mips64) || defined(ARCH_parisc) || defined(ARCH_s390x)
-#define	TASK_LOG_SIZE	2
-#else
-#define	TASK_LOG_SIZE	0
-#endif
-
 int
 search_task(addr)
 	addr_t addr;
@@ -204,7 +204,7 @@ search_task(addr)
 	taddr = init_task_addr;
 	do {
 		memread(taddr, sizeof(tsk), &tsk, "task_struct");
-		if (addr >= taddr && addr < taddr + PAGE_SIZE * (1<<TASK_LOG_SIZE)) {
+		if (addr >= taddr && addr < taddr + STACKSIZE) {
 			mprintf("task_struct pid %d offset %lx\n",
 				tsk.pid, addr - taddr);
 			return 1;
