@@ -142,10 +142,7 @@ print_gfp(gfp)
 #if GFP_USER != GFP_KERNEL
 	case GFP_KERNEL:	p = "KERNEL";	break;
 #endif
-#if GFP_USER != GFP_NFS && GFP_KERNEL != GFP_NFS
-	case GFP_NFS:		p = "NFS";	break;
-#endif
-#if GFP_USER != GFP_KSWAPD && GFP_KERNEL != GFP_KSWAPD && GFP_NFS != GFP_KSWAPD
+#if GFP_USER != GFP_KSWAPD && GFP_KERNEL != GFP_KSWAPD
 	case GFP_KSWAPD:	p = "KSWAPD";	break;
 #endif
 	case GFP_DMA:		p = "DMA";	break;
