@@ -11,7 +11,7 @@
 void
 prhead_zone()
 {
-	mprintf(SPTR "   FREE " SPTR "   SIZE NAME\n", "ADDR", "MEM_MAP");
+	mprintf(SPTR "   FREE " SPTR " NAME\n", "ADDR", "MEM_MAP");
 }
 
 addr_t
@@ -25,8 +25,8 @@ print_zone(addr, full)
 
 	memread(addr, sizeof(zone), &zone, "zone");
 	if (!full) {
-		mprintf(FPTR " %6lx " FPTR " %6lx ",
-			addr, zone.free_pages, zone.zone_mem_map, zone.size);
+		mprintf(FPTR " %6lx " FPTR " ",
+			addr, zone.free_pages, zone.zone_mem_map);
 		memread((addr_t)zone.name, sizeof(buf), &buf, "name");
 		mprint_str(buf, sizeof(buf));
 		mprintf("\n");
@@ -42,13 +42,12 @@ print_zone(addr, full)
 	mprintf("free_pages         %lx\n", zone.free_pages);
 	mprintf("pages_min/low/high %lx/%lx/%lx\n",
 		zone.pages_min, zone.pages_low, zone.pages_high);
-	mprintf("need_balance       %x\n", zone.need_balance);
 	mprintf("refill_counter     %x\n", ATOMIC_READ(zone.refill_counter));
 	mprintf("nr_active          %x\n", zone.nr_active);
 	mprintf("nr_inactive        %x\n", zone.nr_inactive);
 	mprintf("FREE " SPTR " " SPTR "  " SPTR "\n", "NEXT", "PREV", "MAP");
 	for (i = 0; i < MAX_ORDER; i++) {
-		free_area_t *fp = &zone.free_area[i];
+		struct free_area *fp = &zone.free_area[i];
 		mprintf("%3x  ", i);
 		if ((addr_t)fp->free_list.next == addr + OFFSET(struct zone, free_area[i].free_list)) {
 			mprintf(SPTR " ", "-");
@@ -63,6 +62,8 @@ print_zone(addr, full)
 		mprintf(" " FPTR "\n", fp->map);
 	}
 	mprintf("wait_table         " FPTR "\n", zone.wait_table);
+	mprintf("wait_table_size    %lx\n", zone.wait_table_size);
+	mprintf("wait_table_bits    %lx\n", zone.wait_table_bits);
 	mprintf("zone_pgdat         " FPTR "\n", zone.zone_pgdat);
 	mprintf("zone_mem_map       " FPTR "\n", zone.zone_mem_map);
 	mprintf("zone_start_pfn     %lx\n", zone.zone_start_pfn);
@@ -71,7 +72,8 @@ print_zone(addr, full)
 	memread((addr_t)zone.name, sizeof(buf), &buf, "name");
 	mprint_str(buf, sizeof(buf));
 	mprintf("\"\n");
-	mprintf("size               %lx\n", zone.size);
+	mprintf("spanned_pages      %lx\n", zone.spanned_pages);
+	mprintf("present_pages      %lx\n", zone.present_pages);
 	return 0;
 }
 
