@@ -8,6 +8,7 @@
 #include <linux/sched.h>
 #include <linux/file.h>
 
+#include "stacksize.h"
 #include "flags_sched.h"
 
 extern void prhead_vm_area_struct();
@@ -132,10 +133,19 @@ getinfo_fromtask(addr, ip, sp, stack)
 		*ip = tsk.thread.eip;
 	if (sp)
 		*sp = tsk.thread.esp;
-#endif
+#else
 #if defined(ARCH_ia64) || defined(ARCH_ppc)
+	if (ip)
+		*ip = NULL;
 	if (sp)
 		*sp = tsk.thread.ksp;
+#else
+	/* others */
+	if (ip)
+		*ip = NULL;
+	if (sp)
+		*sp = NULL;
+#endif
 #endif
 	if (stack)
 		*stack = (addr_t)tsk.thread_info;
@@ -182,12 +192,6 @@ print_mm_struct(addr, vflag)
 	return (addr_t)mm.mmlist.next - OFFSET(struct mm_struct, mmlist);
 }
 
-#if defined(ARCH_i386)
-#define TASK_LOG_SIZE   1
-#else
-#define TASK_LOG_SIZE   0	/*DUMMY*/
-#endif
-
 int
 search_task(addr)
 	addr_t addr;
@@ -206,7 +210,7 @@ search_task(addr)
 				tsk.pid, addr - taddr);
 			return 1;
 		}
-		if (tsk.thread_info && addr >= (addr_t)tsk.thread_info && addr < (addr_t)tsk.thread_info + PAGE_SIZE * (1 << TASK_LOG_SIZE)) {
+		if (tsk.thread_info && addr >= (addr_t)tsk.thread_info && addr < (addr_t)tsk.thread_info + STACKSIZE) {
 			mprintf("thread_info pid %d offset %lx\n",
 				tsk.pid, addr - (addr_t)tsk.thread_info);
 			return 1;
