@@ -10,13 +10,15 @@
 #include <linux/sched.h>
 #include <linux/module.h>
 #include <linux/blkdev.h>
-#include <linux/lvm.h>
 #include <linux/file.h>
 #include <linux/buffer_head.h>
 #include <linux/namei.h>
 #include <linux/slab.h>
 #include <linux/bio.h>
 #include <linux/namespace.h>
+#include <linux/init.h>
+#include <linux/mount.h>
+#include <linux/net.h>
 #include "slab.h"
 
 struct sizetbl sizetbl[] = {
@@ -31,7 +33,6 @@ struct sizetbl sizetbl[] = {
 	{ "atomic_t",		sizeof(atomic_t) },
 	{ "bio",		sizeof(struct bio) },
 	{ "bio_vec",		sizeof(struct bio_vec) },
-	{ "blk_dev_struct",	sizeof(struct blk_dev_struct) },
 	{ "block_device",	sizeof(struct block_device) },
 	{ "buffer_head",	sizeof(struct buffer_head) },
 	{ "caddr_t",		sizeof(caddr_t) },
@@ -50,8 +51,6 @@ struct sizetbl sizetbl[] = {
 	{ "kmem_cache_t",	sizeof(kmem_cache_t) },
 	{ "list_head",		sizeof(struct list_head) },
 	{ "loff_t",		sizeof(loff_t) },
-	{ "lv_disk_t",		sizeof(lv_disk_t) },
-	{ "lv_t",		sizeof(lv_t) },
 	{ "mm_struct",		sizeof(struct mm_struct) },
 	{ "module",		sizeof(struct module) },
 	{ "nameidata",		sizeof(struct nameidata) },
@@ -60,27 +59,22 @@ struct sizetbl sizetbl[] = {
 	{ "nlink_t",		sizeof(nlink_t) },
 	{ "page",		sizeof(struct page) },
 	{ "pglist_data",	sizeof(struct pglist_data) },
-	{ "pv_disk_t",		sizeof(pv_disk_t) },
-	{ "pv_t",		sizeof(pv_t) },
 	{ "request",		sizeof(struct request) },
 	{ "request_queue",	sizeof(struct request_queue) },
 	{ "semaphore",		sizeof(struct semaphore) },
 	{ "signal_struct",	sizeof(struct signal_struct) },
 	{ "sigpending",		sizeof(struct sigpending) },
 	{ "sigset_t",		sizeof(sigset_t) },
-	{ "slab_t",		sizeof(slab_t) },
+	{ "slab",		sizeof(struct slab) },
 	{ "socket",		sizeof(struct socket) },
 	{ "spinlock_t",		sizeof(spinlock_t) },
 	{ "super_block",	sizeof(struct super_block) },
 	{ "task_struct",	sizeof(struct task_struct) },
 	{ "thread_struct",	sizeof(struct thread_struct) },
 	{ "time_t",		sizeof(time_t) },
-	{ "tq_struct",		sizeof(struct tq_struct) },
 	{ "uid_t",		sizeof(uid_t) },
 	{ "umode_t",		sizeof(umode_t) },
 	{ "vfsmount",		sizeof(struct vfsmount) },
-	{ "vg_disk_t",		sizeof(vg_disk_t) },
-	{ "vg_t",		sizeof(vg_t) },
 	{ "vm_area_struct",	sizeof(struct vm_area_struct) },
 	{ "wait_queue_head_t",	sizeof(wait_queue_head_t) },
 	{ "zone",		sizeof(struct zone) },
