@@ -7,6 +7,7 @@
 #define __KERNEL__
 #include <linux/spinlock.h>
 #include <linux/slab.h>
+#include <linux/init.h>
 #include "slab.h"
 
 addr_t print_slab();
@@ -24,7 +25,7 @@ print_slab(addr, num)
 	addr_t addr;
 	int num;
 {
-	slab_t slab;
+	struct slab slab;
 	kmem_bufctl_t buf[512], ix = slab.free;
 
 	memread(addr, sizeof(slab), &slab, "slab_t");
@@ -53,7 +54,54 @@ print_slab(addr, num)
 		}
 		mprintf("\n");
 	}
-	return (addr_t)slab.list.next - OFFSET(slab_t, list);
+	return (addr_t)slab.list.next - OFFSET(struct slab, list);
+}
+
+addr_t
+print_kmem_list3(addr, num)
+	addr_t addr;
+	int num;
+{
+	struct kmem_list3 list3;
+
+	memread(addr, sizeof(list3), &list3, "kmem_list3");
+	mprintf(FPTR " ", addr);
+	mprintf("slabs_full    " FPTR " " FPTR "\n",
+		list3.slabs_full.next, list3.slabs_full.prev);
+	mprintf("slabs_partial " FPTR " " FPTR "\n",
+		list3.slabs_partial.next, list3.slabs_partial.prev);
+	mprintf("slabs_free    " FPTR " " FPTR "\n",
+		list3.slabs_free.next, list3.slabs_free.prev);
+	mprintf("free_objects  %lx\n", list3.free_objects);
+	mprintf("free_touched  %x\n",  list3.free_touched);
+	mprintf("next_reap     %lx\n", list3.next_reap);
+
+	if (num > 0) {
+		addr_t sad;
+		int none;
+		mprintf("slabs_full:\n");
+		prhead_slab();
+		sad = (addr_t)list3.slabs_full.next - OFFSET(struct slab, list);
+		none = 1;
+		while (sad && sad != addr + OFFSET(struct kmem_list3, slabs_full)) {
+			sad = print_slab(sad, num);
+			none = 0;
+		}
+		if (none)
+			mprintf(SPTR"\n", "(none)");
+
+		mprintf("slabs_partial:\n");
+		prhead_slab();
+		sad = (addr_t)list3.slabs_partial.next - OFFSET(struct slab, list);
+		none = 1;
+		while (sad && sad != addr + OFFSET(struct kmem_list3, slabs_partial)) {
+			sad = print_slab(sad, num);
+			none = 0;
+		}
+		if (none)
+			mprintf(SPTR"\n", "(none)");
+	}
+	return 0;
 }
 
 void
@@ -84,28 +132,21 @@ print_kmem_cache(addr, sflag, full)
 
 	} else {
 		mprintf("addr: " FPTR "\n", addr);
-		mprintf("slabs_full    " FPTR " " FPTR "\n",
-			cache.slabs_full.next, cache.slabs_full.prev);
-		mprintf("slabs_partial " FPTR " " FPTR "\n",
-			cache.slabs_partial.next, cache.slabs_partial.prev);
-		mprintf("slabs_free    " FPTR " " FPTR "\n",
-			cache.slabs_free.next, cache.slabs_free.prev);
 		mprintf("objsize      %x\n", cache.objsize);
 		mprintf("flags        %x\n", cache.flags);
 		mprintf("num          %x\n", cache.num);
+		mprintf("free_limit   %x\n", cache.free_limit);
 		mprintf("gfporder     %x\n", cache.gfporder);
 		mprintf("gfpflags     %x\n", cache.gfpflags);
 		mprintf("colour       %lx\n", cache.colour);
 		mprintf("colour_off   %x\n", cache.colour_off);
 		mprintf("colour_next  %x\n", cache.colour_next);
 		mprintf("slabp_cache   " FPTR "\n", cache.slabp_cache);
-		mprintf("growing      %x\n", cache.growing);
 		mprintf("dflags       %x\n", cache.dflags);
 		p = getsymstr((addr_t)cache.ctor);
 		mprintf("ctor/dtor    %s", p? p: "NULL");
 		p = getsymstr((addr_t)cache.dtor);
 		mprintf("  %s\n", p? p: "NULL");
-		mprintf("failures     %lx\n", cache.failures);
 		mprintf("name         \"");
 		mprint_str(name, sizeof(name));
 		mprintf("\"\n");
@@ -114,29 +155,7 @@ print_kmem_cache(addr, sflag, full)
 	}
 
 	if (sflag) {
-		addr_t sad;
-		int none;
-		mprintf("slabs_full:\n");
-		prhead_slab();
-		sad = (addr_t)cache.slabs_full.next - OFFSET(slab_t, list);
-		none = 1;
-		while (sad && sad != addr + OFFSET(kmem_cache_t, slabs_full)) {
-			sad = print_slab(sad, cache.num);
-			none = 0;
-		}
-		if (none)
-			mprintf(SPTR"\n", "(none)");
-
-		mprintf("slabs_partial:\n");
-		prhead_slab();
-		sad = (addr_t)cache.slabs_partial.next - OFFSET(slab_t, list);
-		none = 1;
-		while (sad && sad != addr + OFFSET(kmem_cache_t, slabs_partial)) {
-			sad = print_slab(sad, cache.num);
-			none = 0;
-		}
-		if (none)
-			mprintf(SPTR"\n", "(none)");
+		print_kmem_list3(addr + OFFSET(kmem_cache_t, lists), cache.num);
 	}
 	return (addr_t)cache.next.next - OFFSET(kmem_cache_t, next);
 }
@@ -148,7 +167,7 @@ search_slab(addr)
 	extern addr_t cache_cache_addr;
 	addr_t kmaddr, saddr;
 	kmem_cache_t cache;
-	slab_t slab;
+	struct slab slab;
 	static char name[64];
 	int len, n;
 
@@ -158,19 +177,19 @@ search_slab(addr)
 		memread((addr_t)cache.name, sizeof(name), name, "kmem_cache_t");
 		len = cache.objsize * cache.num;
 
-		saddr = (addr_t)cache.slabs_full.next - OFFSET(slab_t, list);
-		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, slabs_full)) {
+		saddr = (addr_t)cache.lists.slabs_full.next - OFFSET(struct slab, list);
+		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, lists.slabs_full)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
-			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
+			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
 		}
-		saddr = (addr_t)cache.slabs_partial.next - OFFSET(slab_t, list);
-		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, slabs_partial)) {
+		saddr = (addr_t)cache.lists.slabs_partial.next - OFFSET(struct slab, list);
+		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, lists.slabs_partial)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
-			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
+			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
 		}
 		kmaddr = (addr_t)cache.next.next - OFFSET(kmem_cache_t, next);
 	} while (kmaddr && kmaddr != cache_cache_addr);
