@@ -12,7 +12,7 @@ const commandtable_t command_operations =
 PRIVATE const char *address_space_op[] = {
 	"ADDRESS SPACE OPERATIONS",
 	"writepage", "readpage", "sync_page",
-	"writepages", "vm_writeback", "set_page_dirty", "readpages",
+	"writepages", "set_page_dirty", "readpages",
 	"prepare_write", "commit_write", "bmap", "invalidatepage",
 	"releaspage", "direct_IO",
 	NULL
@@ -20,7 +20,7 @@ PRIVATE const char *address_space_op[] = {
 
 PRIVATE const char *block_device_op[] = {
 	"BLOCK DEVICE OPERATIONS",
-	"open", "release", "ioctl", "check_media_change", "revalidate",
+	"open", "release", "ioctl", "media_changed", "revalidate_disk",
 	"owner",
 	NULL
 };
