@@ -11,7 +11,7 @@ const commandtable_t command_page =
 const commandtable_t command_vm_area_struct =
 	{"vm_area_struct", vm_area_struct, "address", "print vm_area_struct table"};
 const commandtable_t command_zone =
-	{"zone", zone, "address", "print zone_t (or zone_struct) table"};
+	{"zone", zone, "[address]", "print zone_t (or zone_struct) table"};
 const commandtable_t command_pglist_data =
 	{"pglist_data", pglist_data, "[address]", "print pglist_data (or pg_data_t) table"};
 
@@ -116,6 +116,7 @@ zone()
 {
 	int c;
 	addr_t addr = 0;
+	extern void prhead_zone();
 
 	while ((c = getopt(argcnt, args, "")) != EOF) {
 		switch (c) {
@@ -125,10 +126,20 @@ zone()
 	}
 
 	if (optind == argcnt) {
-		THROW(usage);
+		addr_t zaddr;
+		int i;
+		extern addr_t get_zone_from_pglist_data();
+
+		GETADDR(pgdat_list);
+		memread(pgdat_list_addr, sizeof(zaddr), &zaddr, "pgdat_list");
+		prhead_zone();
+		for (i = 0; addr = get_zone_from_pglist_data(zaddr, i); i++) {
+			print_zone(addr, 0);
+		}
+		return addr;
 	}
 	while (args[optind]) {
-		addr = print_zone(getaddr(args[optind]));
+		addr = print_zone(getaddr(args[optind]), 1);
 		optind++;
 	}
 	return addr;
