@@ -2,7 +2,6 @@
 
 extern const commandtable_t
 	command_address_space,
-	command_blk_dev_struct,
 	command_block_device,
 	command_buffer_head,
 	command_char_device,
@@ -31,7 +30,6 @@ extern const commandtable_t
 
 const commandtable_t *commandtable_vers[] = {
 	&command_address_space,
-	&command_blk_dev_struct,
 	&command_block_device,
 	&command_buffer_head,
 	&command_char_device,
