@@ -39,7 +39,7 @@ trace()
 		mprintf("%s+%lx ()\n", sym->name, eip - sym->addr);
 	}
 
-#define	INTHESTACK(x) ((x) >= stacktop && (x) < stacktop + STACKSIZE)
+#define	INTHESTACK(x) ((x) >= stacktop && (x) + sizeof(addr_t) <= stacktop + STACKSIZE)
 	if (!INTHESTACK(esp))
 		return 0;
 	esp = *(unsigned int *)&stack[esp - stacktop] + sizeof(addr_t);
