@@ -39,10 +39,16 @@ module()
 			addr = print_module(addr, full);
 		}
 	} else {
+#if LINUXVER>=25
+		addr_t modules_addr;
+		GETADDR(modules);
+		module_list_addr = modules_addr;
+#else
 		GETADDR(module_list);
+#endif
 		memread(module_list_addr, sizeof(addr), &addr, "module_list");
 		if (!full) prhead_module();
-		while (addr) {
+		while (addr && addr != module_list_addr) {
 			if (full) prhead_module();
 			addr = print_module(addr, full);
 		}
@@ -59,7 +65,7 @@ get_module_symbol(addr)
 {
 	TRY {
 		memread(addr, sizeof(addr), &addr, "module_list");
-		while (addr) {
+		while (addr && addr != module_list_addr) {
 			addr = getmsyms(addr);
 		}
 	} CATCH {
