@@ -142,7 +142,7 @@ init_sym()
 		perror("FATAL: memory allocation");
 		exit(1);
 	}
-	while (fscanf(fp, "%lx %c %s", &addr, &type, buf) == 3) {
+	while (fscanf(fp, "%lx %c %255s", &addr, &type, buf) == 3) {
 		if (addr < 0x40000000)
 			continue;
 		/* type: see info (binutils::nm) */
@@ -240,7 +240,7 @@ getmsyms_fromfile(path, text, data, bss)
 		return 1;
 
 	while (fgets(cmd, sizeof(buf), in) != NULL) {
-		if (sscanf(cmd, "%lx %c %s", &addr, &type, buf) != 3)
+		if (sscanf(cmd, "%lx %c %255s", &addr, &type, buf) != 3)
 			continue;
 		switch (type) {
 		case 't':
@@ -415,21 +415,6 @@ dsymbol()
 	return 0;
 }
 
-void
-mprint_str(p, maxlen)
-	const unsigned char *p;
-	int maxlen;
-{
-	while (--maxlen >= 0 && *p) {
-		if (*p >= ' ' && *p < 0x7f) {
-			mprintf("%c", *p);
-		} else {
-			mprintf("\\x%02x", *p);
-		}
-		p++;
-	}
-}
-
 void
 pmode(aflag)
 	int aflag;
@@ -449,9 +434,16 @@ pmode(aflag)
 	mprintf("%c%03o", ltyp, aflag & 0777);
 }
 
-int
+unsigned int
 m_ntohl(net)
-	int net;
+	unsigned int net;
 {
 	return ntohl(net);
 }
+
+unsigned short
+m_ntohs(net)
+	unsigned short net;
+{
+	return ntohs(net);
+}
