@@ -55,8 +55,10 @@ print_xfs_inode(addr, fflag, rflag)
 
 		mprintf("transp   " FPTR "\n", i.i_transp);
 		mprintf("itemp    " FPTR "\n", i.i_itemp);
+#if 0
 		mprintf("refcache " FPTR "\n", i.i_refcache);
 		mprintf("release  " FPTR "\n", i.i_release);
+#endif
 
 		mprintf("flags        %x\n", i.i_flags);
 		mprintf("update_core  %x\n", i.i_update_core);
