@@ -55,6 +55,8 @@ print_pagebuf(addr, fflag)
 		mprintf("  iodone: " FPTR "\n", pb.pb_iodone);
 		mprintf("  relse:  " FPTR "\n", pb.pb_relse);
 		mprintf("  strat:  " FPTR "\n", pb.pb_strat);
+		mprintf("  locked:    %x\n", pb.pb_locked);
+		mprintf("  fspriv  " FPTR "\n", pb.pb_fspriv);
 		mprintf("  iodonesema:\n");
 #if 1
 		/* new style */
